/**************************************************************************//**
*   @file   adi.h
*   @brief  Contains declarations of functions and constants used by all other
*           project sources.
*   @author ACozma (andrei.cozma@analog.com)
*
*******************************************************************************
* Copyright 2011(c) Analog Devices, Inc.
*
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without modification,
* are permitted provided that the following conditions are met:
*  - Redistributions of source code must retain the above copyright
*    notice, this list of conditions and the following disclaimer.
*  - Redistributions in binary form must reproduce the above copyright
*    notice, this list of conditions and the following disclaimer in
*    the documentation and/or other materials provided with the
*    distribution.
*  - Neither the name of Analog Devices, Inc. nor the names of its
*    contributors may be used to endorse or promote products derived
*    from this software without specific prior written permission.
*  - The use of this software may or may not infringe the patent rights
*    of one or more patent holders.  This license does not release you
*    from the requirement that you obtain separate licenses from these
*    patent holders to use this software.
*  - Use of the software either in source or binary form, must be run
*    on or directly connected to an Analog Devices Inc. component.
*
* THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES "AS IS" AND ANY EXPRESS OR IMPLIED
* WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT, MERCHANTABILITY
* AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
* IN NO EVENT SHALL ANALOG DEVICES BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
* SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
* INTELLECTUAL PROPERTY RIGHTS, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
* LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
* ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
* SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*
*******************************************************************************
*   SVN Revision: 1296
******************************************************************************/
#ifndef __ADI_H__
#define __ADI_H__

/*****************************************************************************/
/******************* Macros and Constants Definitions ************************/
/*****************************************************************************/
//Conditional compile macros
#define USE_uCProbe		1

#define SUCCESS	0
#define FAIL	1

//Definition of the LEDs
#define LED_ALL	0xFF
#define LED_1	(0x01 << 0)
#define LED_2	(0x01 << 1)
#define LED_3	(0x01 << 2)
#define LED_4 	(0x01 << 3)
#define LED_5	(0x01 << 4)
#define LED_6	(0x01 << 5)
#define LED_7	(0x01 << 6)
#define LED_8 	(0x01 << 7)

/*****************************************************************************/
/************************** Types Declarations *******************************/
/*****************************************************************************/
typedef union _uCProbeDataUnion
{
    char            chData;
    unsigned char   uchData;
    short           siData;
    unsigned short  usiData;
    int             iData;
    unsigned int    uiData;
    float           fData;
}uCProbeDataUnion;

/*****************************************************************************/
/************************ Functions Declarations *****************************/
/*****************************************************************************/
extern void SetLed(int aLED);    /*<! Switch on one or more LEDs */
extern void ClearLed(int aLED);  /*<! Switch off one or more LEDs. */
extern void ToggleLed(int aLED); /*<! Change current status of the LED. */
#endif /* __ADI_H__ */
